fnss.netconfig.capacities.set_capacities_betweenness_gravity — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.netconfig.capacities.set_capacities_betweenness_gravity

`set_capacities_betweenness_gravity`(topology, capacities, capacity_unit='Mbps', weighted=True)

  Set link capacities proportionally to the product of the betweenness centralities of the two end-points of the link

  Parameters : | topology : Topology The topology to which link capacities will be set capacities : list A list of all possible capacity values capacity_unit : str, optional The unit in which capacity value is expressed (e.g. Mbps, Gbps etc..) weighted : bool, optional Indicate whether link weights need to be used to compute shortest paths. If links do not have link weights or this parameter is False, shortest paths are calculated based on hop count.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »